// Copyright © 2016 Greg Brown. All rights reserved.

import UIKit
import MarkupKit

class ViewController: UITableViewController {
    @IBOutlet var firstNameTextField: UITextField!
    @IBOutlet var lastNameTextField: UITextField!

    @IBOutlet var streetTextField: UITextField!
    @IBOutlet var cityTextField: UITextField!
    @IBOutlet var stateTextField: UITextField!
    @IBOutlet var statePickerView: LMPickerView!
    @IBOutlet var zipCodeTextField: UITextField!

    @IBOutlet var phoneNumberTextField: UITextField!
    @IBOutlet var emailAddressTextField: UITextField!

    @IBOutlet var dateOfBirthDatePicker: UIDatePicker!

    static let GenderSectionName = "gender"

    override func loadView() {
        // Load view from markup
        view = LMViewBuilder.viewWithName("ViewController", owner: self, root: nil)
    }

    override func viewDidLoad() {
        super.viewDidLoad()

        let mainBundle = NSBundle.mainBundle()

        // Set title
        title = mainBundle.localizedStringForKey("registrationForm", value: nil, table: nil)

        // Load state data
        let stateData = NSData(contentsOfFile: NSBundle.mainBundle().pathForResource("states", ofType: "json")!)
        let states = (try! NSJSONSerialization.JSONObjectWithData(stateData!, options: NSJSONReadingOptions())) as! [[String: AnyObject]]

        for state in states {
            statePickerView.insertRow(statePickerView.numberOfRowsInComponent(0), inComponent: 0,
                withTitle: state["name"] as! String, value: state["code"])
        }

        // Create "submit" button
        navigationItem.rightBarButtonItem = UIBarButtonItem(title: mainBundle.localizedStringForKey("submit", value: nil, table: nil),
            style: UIBarButtonItemStyle.Plain, target: self, action: #selector(ViewController.submitForm))
    }

    @IBAction func cancelStateEdit() {
        // Hide keyboard
        stateTextField.resignFirstResponder()
    }

    @IBAction func updateStateText() {
        // Update state text field and hide keyboard
        stateTextField.text = statePickerView.titleForRow(statePickerView.selectedRowInComponent(0), forComponent: 0)!
        stateTextField.resignFirstResponder()
    }

    func submitForm() {
        // Get selected state code
        let state = (stateTextField.text!.isEmpty) ? "" : statePickerView.valueForRow(statePickerView.selectedRowInComponent(0), forComponent: 0)!

        // Format date of birth
        let dateFormatter = NSDateFormatter()
        
        dateFormatter.dateStyle = .ShortStyle
        dateFormatter.timeStyle = .NoStyle
        
        let dateOfBirth = dateFormatter.stringFromDate(dateOfBirthDatePicker.date)
        
        // Get selected gender
        let genderSection = tableView.sectionWithName(ViewController.GenderSectionName)
        let selectedGenderRow = tableView.rowForCheckedCellInSection(genderSection)
        
        let gender = tableView.cellForRowAtIndexPath(NSIndexPath(forRow: selectedGenderRow, inSection: genderSection))!.value!

        // Simulate form submission
        let form = [
            "firstName": firstNameTextField.text!,
            "lastName": lastNameTextField.text!,
            "street": streetTextField.text!,
            "city": cityTextField.text!,
            "state": state,
            "zipCode": zipCodeTextField.text!,
            "phoneNumber": phoneNumberTextField.text!,
            "emailAddress": emailAddressTextField.text!,
            "dateOfBirth": dateOfBirth,
            "gender": gender
        ]
        
        let data = try! NSJSONSerialization.dataWithJSONObject(form, options: NSJSONWritingOptions.PrettyPrinted)

        print(String(data: data, encoding: NSUTF8StringEncoding)!)
        
        // Display "form submitted" message
        let alertController = UIAlertController(title: "Status", message: "Form submitted.", preferredStyle: .Alert)

        alertController.addAction(UIAlertAction(title: "OK", style: .Default, handler:nil))

        presentViewController(alertController, animated: true, completion: nil)
    }
}

